
import androidx.compose.animation.core.tween
import androidx.compose.animation.fadeIn
import androidx.compose.animation.fadeOut
import androidx.compose.runtime.Composable
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.navigation
import fr.openium.consentium.ui.screens.main.MainScreen
import fr.openium.consentium.ui.screens.splash.SplashScreen

private const val NAV_ANIMATION_TIME = 100

@Composable
fun DemoNavGraph(navHostController: NavHostController) {

    NavHost(
        navController = navHostController,
        startDestination = Destination.Splash,
        enterTransition = {
            fadeIn(animationSpec = tween(NAV_ANIMATION_TIME))
        },
        exitTransition = {
            fadeOut(animationSpec = tween(NAV_ANIMATION_TIME))
        },
    ) {

        composable<Destination.Splash> {
            SplashScreen(
                navigateToMain = { ->
                    navHostController.navigate(Destination.Main) {
                            popUpTo(navHostController.graph.findStartDestination().id) {
                                saveState = true
                            }
                            launchSingleTop = true
                            restoreState = true
                    }
                })
        }

        composable<Destination.Main> {
            MainScreen()
        }

    }
}
